﻿DROP PROCEDURE IF EXISTS sp_GetESL_A03T01_1
GO

CREATE PROCEDURE [dbo].[sp_GetESL_A03T01_1]
   @tanevId int
  ,@feladatEllatasiHelyId int
  ,@isFelevi int = 0 /* 1 - előző tanév végi és féléves; 0 - félévtől év végi */
  ,@osztalyzatTipusTypeID int = 44
AS
BEGIN
  SET NOCOUNT ON;

  CREATE TABLE #tmpRet(
     Kategoria nvarchar(250)
    ,Evfolyam int
    ,Darabszam int
    ,Sorszam int
  )
  CREATE TABLE #tmpRetSum(
     Kategoria nvarchar(250)
    ,Osszesen int
    ,OsszesLany int
  )
  CREATE TABLE #KetFeltetelTanulok (
     Evfolyam int
    ,TanuloId int
    ,Neme int
    ,IsHianyzasMiatt int
    ,IsKiemeltMiatt int
    ,IsGyermekVedelemMiatt int
    ,IsAltalanosIskolaMiatt int
    ,INDEX IX_01 (TanuloId)
  )
  CREATE TABLE #ErintettTanulok (
     Evfolyam int
    ,TanuloId int
    ,Neme int
    ,TanuloNev nvarchar(255)
    ,Oktatasiazonosito nvarchar(11)
    ,TanuloOsztalyNev nvarchar(255)
    ,IsKozepesMiatt int
    ,IsRontasMiatt int
    ,TanuloOsztalyId int
    ,INDEX IX_01 (TanuloId)
  )
  CREATE TABLE #TanuloErtekeles (
     Id int
    ,Tanulo int
    ,Ertekeles int
    ,Tipus int
    ,INDEX IX_01 (Tanulo)
  )

  DECLARE 
     @FelevKezdete date 
    ,@FelevVege date
    ,@ertekelesTipus int
    ,@Kategoria nvarchar(250)
    ,@OsszesLany int

  SET @ertekelesTipus = IIF(@isFelevi = 1, 1519, 1520) /* féléves vagy tév végi jegy */

  SET @FelevKezdete = (
    SELECT C_DATUM + IIF(@isFelevi = 1, 0, 1)
    FROM T_TANEVRENDJE tr
    WHERE C_NAPTIPUSA = IIF(@isFelevi = 1, 1394, 1400) 
      AND tr.C_TANEVID = @tanevid AND tr.TOROLT='F')
  
  SET @FelevVege = (
    SELECT C_DATUM + 1
    FROM T_TANEVRENDJE tr
    WHERE C_NAPTIPUSA = IIF(@isFelevi = 1, 1400, 1395) 
      AND tr.C_TANEVID = @tanevid AND tr.TOROLT='F')

  INSERT INTO #ErintettTanulok (
     TanuloId
    ,Evfolyam
    ,Neme
    ,TanuloNev
    ,OktatasiAzonosito
    ,TanuloOsztalyNev
    ,TanuloOsztalyId
    ,IsKozepesMiatt
    ,IsRontasMiatt
  )
  SELECT * FROM fnGetLemorzsolodottTanulokByFelhely (@feladatEllatasiHelyId, @tanevId, @isFelevi, @osztalyzatTipusTypeID)

  INSERT INTO  #TanuloErtekeles
  SELECT 
     te.ID
    ,C_TANULOID
    ,C_ERTEKELESOSZTALYZATID
    ,C_TIPUSID
  FROM T_TANULOERTEKELES te
    INNER JOIN #ErintettTanulok fht ON fht.TanuloId=te.C_TANULOID
    INNER JOIN T_TANTARGY tgy ON tgy.ID = te.C_TANTARGYID AND (tgy.C_FOTARGYE = 'T' OR tgy.C_ALTANTARGYKENTNYOMTATVANYBAN='T')
      AND C_ESLTANTARGYKATEGORIAID IS NOT NULL AND tgy.TOROLT='F'
  WHERE te.C_TIPUSID=@ertekelesTipus AND te.TOROLT='F' AND te.C_TANEVID = @tanevId
  
  ----------------------------------------------------------------------
  -- PRINT '1'
  ----------------------------------------------------------------------
  -- Szum
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'Osszesen'
  SELECT @OsszesLany = COUNT(DISTINCT TanuloId)
  FROM #ErintettTanulok fh
  WHERE fh.Neme = 5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT TanuloId)
    ,1
  FROM #ErintettTanulok
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum(
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
  
  ----------------------------------------------------------------------
  -- PRINT '2'
  ----------------------------------------------------------------------
  -- Szum lány
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'Lany'
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT TanuloId)
    ,2
  FROM #ErintettTanulok
  WHERE Neme = 5
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum(
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
  
  ----------------------------------------------------------------------
  -- PRINT '3'
  ----------------------------------------------------------------------
  -- Összes rontott
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevErtekelesenelMinositesenelATanuloEgyTizedesjegyigSzamitottTanulmanyiAtlagaAMagatartasEsSzorgalomErtekelesetMinositesetNemBeleszamitvaNemEriElKozepes3Szintet'
  SELECT @Osszeslany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
  WHERE fht.Neme=5 AND IsKozepesMiatt = 1
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT TanuloId)
    ,3
  FROM #ErintettTanulok
  WHERE IsKozepesMiatt = 1
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum(
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '4'
  ----------------------------------------------------------------------
  -- Legalább 1.1-et rontott
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AzEvVegiJegyekAlapjanAFeleviJegyekhezKepestLegalabb11NyiAtlagotRontoTanulokSzama'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
  WHERE fht.Neme=5 AND IsRontasMiatt = 1
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT TanuloId)
    ,4
  FROM #ErintettTanulok
  WHERE IsRontasMiatt = 1
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum(
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
  
  ----------------------------------------------------------------------
  -- PRINT '5'
  ----------------------------------------------------------------------
  -- egy, vagy több tantárgyból elégtelen osztályzat
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevErtekelesenelMinositesenelATanuloEgyVagyTobbTantargybolElegtelen1OsztalyzatotKapott'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #TanuloErtekeles te
    INNER JOIN #ErintettTanulok fht ON fht.TanuloId=te.Tanulo AND fht.Neme = 5
  WHERE te.Tipus = @ertekelesTipus AND te.Ertekeles = 1501
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,5
  FROM #ErintettTanulok t
    INNER JOIN #TanuloErtekeles te ON te.Tanulo = t.TanuloId
  WHERE te.Tipus = @ertekelesTipus AND te.Ertekeles = 1501
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
  
  ----------------------------------------------------------------------
  -- PRINT '6'
  ----------------------------------------------------------------------
  -- félév, magatartás, 2
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevMagatartasanakErtekelesenelMinositesenelATanuloRossz2ErtekelestKapott'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULOERTEKELES te ON te.C_TANULOID=fht.TanuloId AND fht.Neme = 5 AND te.C_ISMAGATARTASSZORGALOM = 'T'
      AND (te.C_MAGATARTASERTEKID=1558 OR te.C_MAGATARTASOSZTALYZATID=1502) AND te.C_TIPUSID = @ertekelesTipus
      AND te.TOROLT='F'
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,6
  FROM #ErintettTanulok t
    INNER JOIN T_TANULOERTEKELES te ON te.C_TANULOID=t.TanuloId AND te.C_ISMAGATARTASSZORGALOM = 'T'
      AND (te.C_MAGATARTASERTEKID=1558 OR te.C_MAGATARTASOSZTALYZATID=1502) AND te.C_TIPUSID = @ertekelesTipus
      AND te.TOROLT='F'
  GROUP BY Evfolyam
 
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
    
  ----------------------------------------------------------------------
  -- PRINT '7'
  ----------------------------------------------------------------------
  -- félév, szorgalom, 2
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevSzorgalmanakErtekelesenelMinositesenelATanuloHanyag2ErtekelestKapott'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULOERTEKELES te ON te.C_TANULOID=fht.TanuloId AND fht.Neme = 5 AND te.C_ISMAGATARTASSZORGALOM = 'T'
      AND (te.C_SZORGALOMERTEKID = 1562 OR te.C_SZORGALOMOSZTALYZATID=1502)
      AND te.TOROLT='F' AND te.C_TIPUSID = @ertekelesTipus
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,7
  FROM #ErintettTanulok t
    INNER JOIN T_TANULOERTEKELES te ON te.C_TANULOID=t.TanuloId AND te.C_ISMAGATARTASSZORGALOM = 'T'
      AND (te.C_SZORGALOMERTEKID = 1562 OR te.C_SZORGALOMOSZTALYZATID=1502)
      AND te.TOROLT='F' AND te.C_TIPUSID = @ertekelesTipus
  GROUP BY Evfolyam

  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
    
  ----------------------------------------------------------------------
  -- PRINT '8'
  ----------------------------------------------------------------------
  -- adott évben évismétlés 
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AzAdottTanitasiEvbenEvismetlesreKotelezett'
  IF @isFelevi = 0 
  BEGIN
    SET @OsszesLany = (
      SELECT SUM(x.db) FROM(
        SELECT COUNT(DISTINCT fht.TanuloId) db
        FROM #ErintettTanulok fht
          INNER JOIN #tanuloErtekeles te ON te.Tanulo=fht.TanuloId AND te.Ertekeles=1501
        WHERE fht.Neme=5
        GROUP BY fht.TanuloId
        HAVING COUNT(*)>=4) x)

     INSERT INTO #tmpRet(
       Kategoria
      ,Evfolyam 
      ,Darabszam
      ,Sorszam
    ) SELECT
       @Kategoria
      ,Evfolyam
      ,COUNT(DISTINCT x.TanuloId)
      ,8
    FROM(
      SELECT 
         t.TanuloId
        ,t.Evfolyam
      FROM #ErintettTanulok t
        INNER JOIN #tanuloErtekeles te ON te.Tanulo=t.TanuloId AND te.Ertekeles=1501
      GROUP BY t.TanuloId,t.Evfolyam
      HAVING COUNT(*)>=4) x
    GROUP BY Evfolyam

    INSERT INTO #tmpRetSum (
       Kategoria 
      ,Osszesen 
      ,OsszesLany
    ) SELECT
       @Kategoria
      ,SUM(Darabszam)
      ,@OsszesLany
    FROM #tmpRet
    WHERE Kategoria = @Kategoria
  END
  
  ----------------------------------------------------------------------
  -- PRINT '9'
  ----------------------------------------------------------------------
  -- Félévben 50 órát elérő igazolatlan hiányzás
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevbenATanulo50OratMeghaladoHianyzassalRendelkezik'
  SELECT @OsszesLany = COUNT(DISTINCT Tanulo) FROM (
    SELECT 
      fht.Tanuloid AS Tanulo 
    FROM T_TANULOMULASZTAS tm
      INNER JOIN #ErintettTanulok fht on fht.TanuloId=tm.C_ORATANULOIID AND fht.Neme=5
      INNER JOIN T_TANITASIORA tao on tao.ID=tm.C_TANITASIORAKID AND tao.C_DATUM >= @FelevKezdete AND tao.C_DATUM < @FelevVege
        AND tao.TOROLT='F'
      LEFT JOIN T_CSOPORT cs ON cs.ID = tao.C_OSZTALYCSOPORTID AND cs.C_TIPUSA NOT IN (SELECT ID FROM fnGetTanoraiCeluCsoportTipusok(@tanevId))
        AND cs.TOROLT='F'
    WHERE tm.C_IGAZOLT='F' AND cs.ID IS NULL AND tm.TOROLT='F'
    GROUP BY fht.TanuloId
    HAVING COUNT(Tanuloid) > 50) a
  
  INSERT INTO #tmpRet(
       Kategoria
      ,Evfolyam 
      ,Darabszam
      ,Sorszam
    ) SELECT
       @Kategoria
      ,Evfolyam
      ,COUNT(DISTINCT x.TanuloId)
      ,9
    FROM(
      SELECT 
        fht.Tanuloid
       ,fht.Evfolyam
      FROM T_TANULOMULASZTAS tm
        INNER JOIN #ErintettTanulok fht ON fht.TanuloId=tm.C_ORATANULOIID
        INNER JOIN T_TANITASIORA tao ON tao.ID=tm.C_TANITASIORAKID AND tao.C_DATUM >= @FelevKezdete AND tao.C_DATUM < @FelevVege
          AND tao.TOROLT='F'
        LEFT JOIN T_CSOPORT cs ON cs.ID = tao.C_OSZTALYCSOPORTID
          AND cs.C_TIPUSA NOT IN (SELECT ID FROM fnGetTanoraiCeluCsoportTipusok(@tanevId))
          AND cs.TOROLT='F'
      WHERE tm.C_IGAZOLT='F' AND cs.ID IS NULL AND tm.TOROLT='F'
      GROUP BY fht.TanuloId, fht.Evfolyam
    HAVING COUNT(TanuloId) > 50) x
  GROUP BY Evfolyam

  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
    
  ----------------------------------------------------------------------
  -- PRINT '10'
  ----------------------------------------------------------------------
  -- Szülő kérésére magántanuló
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevbenSzuloiKeresreMagantanulovaValtTanulo'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULOCSOPORT tcs ON tcs.C_OSZTALYCSOPORTID=fht.TanuloOsztalyId AND tcs.C_TANULOID=fht.TanuloId
      AND tcs.TOROLT='F'
    INNER JOIN T_TANULOTANUGYIADATOK tta ON tta.C_TANULOCSOPORTID=tcs.ID AND tta.C_MAGANTANULOSAGANAKOKAID IN (663, 664)
      AND tta.TOROLT='F'
  WHERE fht.Neme=5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT fht.TanuloId)
    ,10
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULOCSOPORT tcs ON tcs.C_OSZTALYCSOPORTID=fht.TanuloOsztalyId AND tcs.C_TANULOID=fht.TanuloId
      AND tcs.TOROLT='F'
    INNER JOIN T_TANULOTANUGYIADATOK tta ON tta.C_TANULOCSOPORTID=tcs.ID AND tta.C_MAGANTANULOSAGANAKOKAID IN (663, 664)
      AND tta.TOROLT='F'
  GROUP BY Evfolyam

  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '11'
  ----------------------------------------------------------------------
  -- Menekült, menedékjoggal rendelkező
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevbenMenekultOltalmazottMenedekesTanulokSzama'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULO t ON t.C_MENEDEKJOGGALRENDELKEZO='T' AND fht.TanuloId=t.ID AND fht.Neme=5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT fht.TanuloId)
    ,11
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULO t ON t.C_MENEDEKJOGGALRENDELKEZO='T' AND fht.TanuloId=t.ID
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '12'
  ----------------------------------------------------------------------
  -- Félévben veszélyeztetett tanulók száma
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevbenVeszelyezeztetteValtTanulokSzama'
  SELECT @OsszesLany = COUNT(DISTINCT TanuloId)
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULO t on t.ID=fht.TanuloId AND t.C_VESZELYEZTETETT='T' AND fht.Neme=5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT fht.TanuloId)
    ,12
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULO t on t.ID=fht.TanuloId AND t.C_VESZELYEZTETETT='T'
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '13'
  ----------------------------------------------------------------------
  -- ideiglenes hatállyal elhelyezett vagy nevelésbe vett tanulók
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'AFelevbenIdeiglenesHatallyalElhelyezettVagyNevelesbeVettTanulokSzama'
  SELECT @OsszesLany = COUNT(DISTINCT fht.TanuloId)
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULO t ON t.C_ALLAMIGONDOZOTT='T' AND fht.TanuloId=t.ID AND fht.Neme=5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT fht.TanuloId)
    ,13
  FROM #ErintettTanulok fht
    INNER JOIN T_TANULO t ON t.C_ALLAMIGONDOZOTT='T' AND fht.TanuloId=t.ID
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '14'
  ----------------------------------------------------------------------
  -- legalább 2 feltétel teljesül
  ----------------------------------------------------------------------
  -- Alapadatok
  
  INSERT INTO #KetFeltetelTanulok
  SELECT DISTINCT
     ftt.Evfolyam
    ,ftt.TanuloId
    ,ftt.Neme
    ,IIF((SELECT COUNT(1)
         FROM T_TANULOMULASZTAS tm 
           INNER JOIN T_TANITASIORA tno ON tno.ID = tm.C_TANITASIORAKID
             AND tno.C_DATUM >= @FelevKezdete
             AND tno.C_DATUM < @FelevVege
            AND tno.TOROLT='F'
           LEFT JOIN T_CSOPORT cs ON cs.ID = tno.C_OSZTALYCSOPORTID AND cs.TOROLT='F'
         WHERE (cs.ID IS NULL OR cs.C_TIPUSA IN (SELECT ID FROM fnGetTanoraiCeluCsoportTipusok(@tanevId)))
           AND tm.TOROLT='F'
          AND tm.C_IGAZOLT='T'
           AND tm.C_TIPUS = 1500
           AND tm.C_ORATANULOIID = ftt.TanuloId) > 100, 1, 0) AS IsHianyzasMiatt
    ,IIF((SELECT COUNT(1)
         FROM T_TANULO t
         WHERE t.ID = ftt.TanuloId
           AND (t.C_SAJATOSNEVELESU='T' OR t.C_BTMPROBLEMAS='T' OR t.C_HATRANYOSHELYZETU IN (1122, 1123))) > 0, 1, 0) AS IsKiemeltMiatt
    ,IIF((SELECT COUNT(1)
         FROM T_TANULO t
         WHERE t.ID = ftt.TanuloId 
           AND t.C_RENDSZERESGYERMEKVEDELMIKEDV IS NOT NULL) > 0, 1, 0) AS IsGyermekVedelemMiatt
    ,IIF((SELECT COUNT(1)
         FROM T_FELHASZNALO t
          INNER JOIN T_TANULOCSOPORT tcs ON tcs.C_TANULOID=t.ID AND tcs.TOROLT='F'
          INNER JOIN T_OSZTALYCSOPORT ocs ON ocs.ID=tcs.C_OSZTALYCSOPORTID AND ocs.TOROLT='F'
          INNER JOIN T_TANULOTANUGYIADATOK tta ON tta.C_TANULOCSOPORTID = tcs.ID AND tta.C_ISESL16EVESUTANBELEPETT = 'T' AND tta.TOROLT='F'
           INNER JOIN T_FELADATELLATASIHELY fh ON fh.ID=ocs.C_FELADATELLATASIHELYID AND fh.C_OKTATASINEVELESIFELADATTIPUS IN (1158,1178)
             AND fh.ID = @feladatEllatasiHelyId AND fh.TOROLT='F'
         WHERE t.ID = ftt.TanuloId) > 0, 1, 0) AS IsAltalanosIskolaMiatt
  FROM #ErintettTanulok ftt

  DELETE kt FROM #KetFeltetelTanulok kt WHERE (kt.IsHianyzasMiatt + kt.IsKiemeltMiatt + kt.IsGyermekVedelemMiatt + kt.IsAltalanosIskolaMiatt) < 2
  --Alapadatok vége

  SET @Kategoria = 'KettoFeltetelTelejesuleseEsetenLemorzsolodassalVeszelyeztetettTanulo'
  SELECT @OsszesLany = COUNT(DISTINCT ft.TanuloId)
  FROM #KetFeltetelTanulok ft
  WHERE ft.Neme=5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,14
  FROM #KetFeltetelTanulok t
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '15'
  ----------------------------------------------------------------------
  -- kettő feltétel esetén ... félévben 100 órát elért igazolt hiányzás
  ----------------------------------------------------------------------
 
  SET @Kategoria = 'EbbolAFelevben100OratEleroIgazoltHianyzassalRendelkezoTanulokSzama'
  SELECT @OsszesLany = COUNT(DISTINCT kt.TanuloId)
  FROM #KetFeltetelTanulok kt
  WHERE kt.IsHianyzasMiatt = 1 AND kt.Neme = 5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,15
  FROM #KetFeltetelTanulok t
  WHERE t.IsHianyzasMiatt = 1
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '16'
  ----------------------------------------------------------------------
  -- kettő feltétel ... kiemelet figyelmet igénylő --sni, btmn, hh, 3h
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'EbbolKiemeltFigyelmetIgenyloTanulokSzamaAKiemeltenTehetsegesTanulokKivetelevel'
  SELECT @OsszesLany = COUNT(DISTINCT kt.TanuloId)
  FROM #KetFeltetelTanulok kt
  WHERE kt.IsKiemeltMiatt = 1 AND kt.Neme = 5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,16
  FROM #KetFeltetelTanulok t
  WHERE t.IsKiemeltMiatt = 1
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '17'
  ----------------------------------------------------------------------
  -- kettő feltétel ... --rendszeres gyermekvédelmi támogatás
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'EbbolRendszeresGyermekvedelmiKedvezmenybenReszesuloTanulokSzama'
  SELECT @OsszesLany = COUNT(DISTINCT kt.TanuloId)
  FROM #KetFeltetelTanulok kt
  WHERE kt.IsGyermekVedelemMiatt = 1 AND kt.Neme = 5
  
   INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(DISTINCT t.TanuloId)
    ,17
  FROM #KetFeltetelTanulok t
  WHERE t.IsGyermekVedelemMiatt = 1
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria

  ----------------------------------------------------------------------
  -- PRINT '18'
  ----------------------------------------------------------------------
  -- kettő feltétel ... alapfokú oktatásban 16
  ----------------------------------------------------------------------
  
  SET @Kategoria = 'EbbolAlapfokuOktatasbanBetoltotteA16Eletevet'
  SELECT @OsszesLany = COUNT(DISTINCT kt.TanuloId)
  FROM #KetFeltetelTanulok kt
  WHERE kt.IsAltalanosIskolaMiatt = 1 AND kt.Neme = 5
  
  INSERT INTO #tmpRet(
     Kategoria
    ,Evfolyam 
    ,Darabszam
    ,Sorszam
  ) SELECT
     @Kategoria
    ,Evfolyam
    ,COUNT(t.TanuloId)
    ,17
  FROM #KetFeltetelTanulok t
  WHERE t.IsAltalanosIskolaMiatt = 1
  GROUP BY Evfolyam
  
  INSERT INTO #tmpRetSum (
     Kategoria 
    ,Osszesen 
    ,OsszesLany
  ) SELECT
     @Kategoria
    ,SUM(Darabszam)
    ,@OsszesLany
  FROM #tmpRet
  WHERE Kategoria = @Kategoria
  
  ----------------------------------------------------------------------
  -- SELECT
  ----------------------------------------------------------------------
  SELECT
     t.Kategoria
    ,t.Evfolyam
    ,ISNULL(t.Darabszam,0) as Darabszam
    ,s.Osszesen
    ,s.OsszesLany
  FROM #tmpRet t
    INNER JOIN #tmpRetSum s ON s.Kategoria = t.Kategoria
  ORDER BY t.Sorszam

END
GO
